@@ -1,8 +1,7 @@
 package PICA::Parser::PPXML;
-use strict;
-use warnings;
+use v5.14.1;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use parent 'PICA::Parser::XML';
 
@@ -10,27 +9,31 @@ sub _next_record {
     my ($self) = @_;
 
     my $reader = $self->{xml_reader};
-    return unless $reader->nextElement('record','http://www.oclcpica.org/xmlns/ppxml-1.0');
+    return
+        unless $reader->nextElement('record',
+        'http://www.oclcpica.org/xmlns/ppxml-1.0');
 
     my @record;
 
     # get all field from PICA record;
-    foreach my $field ( $reader->copyCurrentNode(1)->getElementsByLocalName('tag') ) {
+    foreach
+        my $field ($reader->copyCurrentNode(1)->getElementsByLocalName('tag'))
+    {
         my @field;
-        
+
         # get field tag number
-        my $tag = $field->getAttribute('id');
+        my $tag        = $field->getAttribute('id');
         my $occurrence = $field->getAttribute('occ') // '';
         push(@field, ($tag, $occurrence));
-            
-            # get all subfields
-            foreach my $subfield ( $field->getElementsByLocalName('subf') ) {
-                my $subfield_code = $subfield->getAttribute('id');
-                my $subfield_data = $subfield->textContent;
-                push(@field, ($subfield_code, $subfield_data));
-            }
+
+        # get all subfields
+        foreach my $subfield ($field->getElementsByLocalName('subf')) {
+            my $subfield_code = $subfield->getAttribute('id');
+            my $subfield_data = $subfield->textContent;
+            push(@field, ($subfield_code, $subfield_data));
+        }
         push(@record, [@field]);
-    };
+    }
 
     return \@record;
 }
