@@ -1,23 +1,22 @@
 package PICA::Parser::Plain;
-use strict;
-use warnings;
+use v5.14.1;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use charnames ':full';
 use Carp qw(carp croak);
 
 use parent 'PICA::Parser::Base';
 
-sub SUBFIELD_INDICATOR { '$' }
-sub END_OF_FIELD       { "\N{LINE FEED}" }
-sub END_OF_RECORD      { "\N{LINE FEED}" }
+sub SUBFIELD_INDICATOR {'$'}
+sub END_OF_FIELD       {"\N{LINE FEED}"}
+sub END_OF_RECORD      {"\N{LINE FEED}"}
 
 sub _next_record {
     my ($self) = @_;
 
     my $plain = undef;
-    while ( my $line = $self->{reader}->getline ) {
+    while (my $line = $self->{reader}->getline) {
         last if $line =~ /^\s*$/;
         $plain .= $line;
     }
@@ -26,17 +25,17 @@ sub _next_record {
     chomp $plain;
     my @fields = split $self->END_OF_FIELD, $plain;
     my @record;
-    
+
     for my $field (@fields) {
 
-        my ( $tag, $occurence, $data );
-        if ( $field =~ m/^(\d{3}[A-Z@])(\/(\d{2,3}))?\s(.+)/ ) {
+        my ($tag, $occurence, $data);
+        if ($field =~ m/^(\d{3}[A-Z@])(\/(\d{2,3}))?\s(.+)/) {
             $tag       = $1;
             $occurence = $3 // '';
             $data      = $4;
         }
         else {
-            if ( $self->{strict} ) {
+            if ($self->{strict}) {
                 croak "ERROR: no valid PICA field structure \"$field\"";
             }
             else {
@@ -46,26 +45,26 @@ sub _next_record {
             }
         }
 
-
         # data is byte sequence, no character sequence!
         my @subfields = split /\$(\$+|.)/, $data;
         shift @subfields;
-        push @subfields, '' if @subfields % 2; # last subfield without value
+        push @subfields, '' if @subfields % 2;   # last subfield without value
 
         if ($data =~ /\$\$/) {
             my @tokens = (shift @subfields, shift @subfields);
             while (@subfields) {
                 my $code  = shift @subfields;
                 my $value = shift @subfields;
-                if  ($code =~ /^\$+$/) {
+                if ($code =~ /^\$+$/) {
                     my $length = length $code;
                     $code =~ s/\$\$/\$/g;
                     if ($length % 2) {
                         $tokens[-1] .= "$code$value";
                         next;
-                    } else {
+                    }
+                    else {
                         $tokens[-1] .= $code;
-                        $code = substr $value, 0, 1; 
+                        $code  = substr $value, 0, 1;
                         $value = substr $value, 1;
                     }
                 }
@@ -74,7 +73,7 @@ sub _next_record {
             @subfields = @tokens;
         }
 
-        push @record, [ $tag, $occurence, @subfields ];
+        push @record, [$tag, $occurence, @subfields];
     }
     return \@record;
 }
