@@ -1,21 +1,20 @@
 package PICA::Parser::Plus;
-use strict;
-use warnings;
+use v5.14.1;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use charnames qw(:full);
 use Carp qw(carp croak);
 
 use parent 'PICA::Parser::Base';
 
-sub SUBFIELD_INDICATOR { "\N{INFORMATION SEPARATOR ONE}" }
-sub END_OF_FIELD       { "\N{INFORMATION SEPARATOR TWO}" }
-sub END_OF_RECORD      { "\N{LINE FEED}" }
+sub SUBFIELD_INDICATOR {"\N{INFORMATION SEPARATOR ONE}"}
+sub END_OF_FIELD       {"\N{INFORMATION SEPARATOR TWO}"}
+sub END_OF_RECORD      {"\N{LINE FEED}"}
 
 sub _next_record {
     my ($self) = @_;
-     
+
     # TODO: does only work if END_OF_RECORD is LINE FEED
     local $/ = $self->END_OF_RECORD;
     my $line = $self->{reader}->getline // return;
@@ -24,20 +23,21 @@ sub _next_record {
     my @fields = split $self->END_OF_FIELD, $line;
     my @record;
 
-    if (@fields and index($fields[0],$self->SUBFIELD_INDICATOR) == -1) {
+    if (@fields and index($fields[0], $self->SUBFIELD_INDICATOR) == -1) {
+
         # drop leader because usage is unclear
         shift @fields;
     }
 
     foreach my $field (@fields) {
         my ($tag, $occurence, $data);
-        if ( $field =~ m/^(\d{3}[A-Z@])(\/(\d{2,3}))?\s(.+)/ ) {
+        if ($field =~ m/^(\d{3}[A-Z@])(\/(\d{2,3}))?\s(.+)/) {
             $tag       = $1;
             $occurence = $3 // '';
             $data      = $4;
         }
         else {
-            if ( $self->{strict} ) {
+            if ($self->{strict}) {
                 croak "ERROR: no valid PICA field structure \"$field\"";
             }
             else {
@@ -47,9 +47,9 @@ sub _next_record {
             }
         }
 
-        my @subfields = map { substr( $_, 0, 1 ), substr( $_, 1 ) }
-                        split( $self->SUBFIELD_INDICATOR, substr( $data, 1 ) );
-        push @record, [ $tag, $occurence, @subfields ];
+        my @subfields = map {substr($_, 0, 1), substr($_, 1)}
+            split($self->SUBFIELD_INDICATOR, substr($data, 1));
+        push @record, [$tag, $occurence, @subfields];
     }
 
     return \@record;
