@@ -1,8 +1,7 @@
 package PICA::Writer::XML;
-use strict;
-use warnings;
+use v5.14.1;
 
-our $VERSION = '1.07';
+our $VERSION = '1.08';
 
 use Scalar::Util qw(reftype);
 use XML::Writer;
@@ -11,27 +10,31 @@ use parent 'PICA::Writer::Base';
 
 sub new {
     my $self = PICA::Writer::Base::new(@_);
-    $self->{writer} = XML::Writer->new(OUTPUT => $self->{fh}, DATA_MODE => 1, DATA_INDENT => 2);
+    $self->{writer} = XML::Writer->new(
+        OUTPUT      => $self->{fh},
+        DATA_MODE   => 1,
+        DATA_INDENT => 2
+    );
     $self->{writer}->xmlDecl('UTF-8');
-    $self->{writer}->startTag('collection', xmlns => 'info:srw/schema/5/picaXML-v1.0');
+    $self->{writer}
+        ->startTag('collection', xmlns => 'info:srw/schema/5/picaXML-v1.0');
     $self;
 }
 
-
 sub write_record {
     my ($self, $record) = @_;
     $record = $record->{record} if reftype $record eq 'HASH';
 
     my $writer = $self->{writer};
-    my $schema = $self->{schema} // { field => { } };
+    my $schema = $self->{schema} // {field => {}};
 
     $writer->startTag('record');
     foreach my $field (@$record) {
-        my $id = $field->[0];
+        my $id   = $field->[0];
         my @attr = (tag => $field->[0]);
-        if ( defined $field->[1] && $field->[1] ne '') {
+        if (defined $field->[1] && $field->[1] ne '') {
             push @attr, occurrence => $field->[1];
-            $id = "$id/".$field->[1];
+            $id = "$id/" . $field->[1];
         }
         my $fielddef = $schema->{fields}{$id};
         my $sfdef;
@@ -43,11 +46,11 @@ sub write_record {
             }
             $sfdef = $fielddef->{subfields};
         }
-        $writer->startTag('datafield', @attr );
-        for (my $i=2; $i<scalar @$field; $i+=2) {
-            my $code = $field->[$i];
-            my $value = $field->[$i+1];
-            my @attr = (code => $code);
+        $writer->startTag('datafield', @attr);
+        for (my $i = 2; $i < scalar @$field; $i += 2) {
+            my $code  = $field->[$i];
+            my $value = $field->[$i + 1];
+            my @attr  = (code => $code);
             if ($sfdef && $sfdef->{$code}) {
                 foreach (qw(label url pica3)) {
                     if (defined $sfdef->{$code}{$_}) {
@@ -56,7 +59,7 @@ sub write_record {
                 }
             }
             $writer->dataElement('subfield', $value, @attr);
-        } 
+        }
         $writer->endTag('datafield');
     }
     $writer->endTag('record');
@@ -64,8 +67,8 @@ sub write_record {
 
 sub end {
     my $self = shift;
-     $self->{writer}->endTag('collection');
-     $self->{writer}->end();
+    $self->{writer}->endTag('collection');
+    $self->{writer}->end();
 }
 
 1;
